@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -60,11 +60,6 @@ void GravatarConfigureSettingsDialogTest::shouldHaveDefaultValue()
     QVERIFY(fallbackGravatar);
     QVERIFY(!fallbackGravatar->isEnabled());
 
-#if 0
-    QCheckBox *useHttps = dlg.findChild<QCheckBox *>(QStringLiteral("usehttps"));
-    QVERIFY(useHttps);
-#endif
-
     KSeparator *separator = dlg.findChild<KSeparator *>(QStringLiteral("separator"));
     QVERIFY(separator);
 
